@@ -25,8 +25,8 @@
 
 namespace ArchiveMailAgentUtil {
 static QString archivePattern = QStringLiteral("ArchiveMailCollection %1");
-QDate diffDate(ArchiveMailInfo *info);
-bool needToArchive(ArchiveMailInfo *info);
+Q_REQUIRED_RESULT QDate diffDate(ArchiveMailInfo *info);
+Q_REQUIRED_RESULT bool needToArchive(ArchiveMailInfo *info);
 }
 
 #endif // ARCHIVEMAILAGENTUTIL_H
