@@ -34,10 +34,12 @@ public:
 
     void setInfo(const QList<FollowUpReminder::FollowUpReminderInfo *> &info);
 
+    void wakeUp();
 Q_SIGNALS:
     void needToReparseConfiguration();
 
 private:
+    void slotDBusNotificationsPropertiesChanged(const QString &interface, const QVariantMap &changedProperties, const QStringList &invalidatedProperties);
     void slotSave();
     void readConfig();
     void writeConfig();
