@@ -98,15 +98,11 @@ FilterLogDialog::FilterLogDialog(QWidget *parent)
     }
 
     MailfilterPurposeMenuWidget *purposeMenu = new MailfilterPurposeMenuWidget(this, this);
-    if (purposeMenu->menu()) {
-        QPushButton *mShareButton = new QPushButton(i18n("Share..."), this);
-        mShareButton->setMenu(purposeMenu->menu());
-        mShareButton->setIcon(QIcon::fromTheme(QStringLiteral("document-share")));
-        purposeMenu->setEditorWidget(mTextEdit->editor());
-        buttonBox->addButton(mShareButton, QDialogButtonBox::ActionRole);
-    } else {
-        delete purposeMenu;
-    }
+    QPushButton *mShareButton = new QPushButton(i18n("Share..."), this);
+    mShareButton->setMenu(purposeMenu->menu());
+    mShareButton->setIcon(QIcon::fromTheme(QStringLiteral("document-share")));
+    purposeMenu->setEditorWidget(mTextEdit->editor());
+    buttonBox->addButton(mShareButton, QDialogButtonBox::ActionRole);
 
     mLogActiveBox = new QCheckBox(i18n("&Log filter activities"), page);
     pageVBoxLayout->addWidget(mLogActiveBox);
@@ -180,7 +176,7 @@ FilterLogDialog::FilterLogDialog(QWidget *parent)
     mLogMemLimitSpin->setSuffix(i18n(" KB"));
     mLogMemLimitSpin->setSpecialValueText(
         i18nc("@label:spinbox Set the size of the logfile to unlimited.", "unlimited"));
-    connect(mLogMemLimitSpin, QOverload<int>::of(&QSpinBox::valueChanged), this, &FilterLogDialog::slotChangeLogMemLimit);
+    connect(mLogMemLimitSpin, qOverload<int>(&QSpinBox::valueChanged), this, &FilterLogDialog::slotChangeLogMemLimit);
     mLogMemLimitSpin->setWhatsThis(
         i18n("Collecting log data uses memory to temporarily store the "
              "log data; here you can limit the maximum amount of memory "
