@@ -138,7 +138,8 @@ void SendLaterAgent::configure(WId windowId)
 {
     QPointer<SendLaterConfigureDialog> dialog = new SendLaterConfigureDialog();
     if (windowId) {
-        KWindowSystem::setMainWindow(dialog, windowId);
+        dialog->setAttribute(Qt::WA_NativeWindow, true);
+        KWindowSystem::setMainWindow(dialog->windowHandle(), windowId);
     }
     connect(this, &SendLaterAgent::needUpdateConfigDialogBox, dialog.data(), &SendLaterConfigureDialog::slotNeedToReloadConfig);
     connect(dialog.data(), &SendLaterConfigureDialog::sendNow, this, &SendLaterAgent::slotSendNow);
@@ -154,6 +155,13 @@ void SendLaterAgent::configure(WId windowId)
     delete dialog;
 }
 
+void SendLaterAgent::removeItem(qint64 item)
+{
+    if (mManager->itemRemoved(item)) {
+        reload();
+    }
+}
+
 void SendLaterAgent::slotSendNow(Akonadi::Item::Id id)
 {
     mManager->sendNow(id);
@@ -161,8 +169,14 @@ void SendLaterAgent::slotSendNow(Akonadi::Item::Id id)
 
 void SendLaterAgent::itemsRemoved(const Akonadi::Item::List &items)
 {
+    bool needToReload = false;
     for (const Akonadi::Item &item : items) {
-        mManager->itemRemoved(item.id());
+        if (mManager->itemRemoved(item.id())) {
+            needToReload = true;
+        }
+    }
+    if (needToReload) {
+        reload();
     }
 }
 
