@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -24,7 +24,7 @@ class DisplayMessageFormatActionMenuTest : public QObject
 {
     Q_OBJECT
 public:
-    DisplayMessageFormatActionMenuTest();
+    explicit DisplayMessageFormatActionMenuTest(QObject *parent = nullptr);
 private Q_SLOTS:
     void shouldHaveDefaultValue();
     void shouldEmitSignalWhenClickOnSubMenu();
