@@ -109,7 +109,7 @@ QTextDocument *ConfigAgentDelegate::document(const QStyleOptionViewItem &option,
         "<tr>"
         "<td rowspan=\"2\"><img src=\"agent_icon\">&nbsp;&nbsp;</td>"
         "<td><b>%2</b></td>"
-        "</tr>").arg(textColor.name().toUpper()).arg(name)
+        "</tr>").arg(textColor.name().toUpper(), name)
                             + QStringLiteral(
         "<tr>"
         "<td><img src=\"status_icon\"/> %1 %2</td>"
@@ -218,7 +218,7 @@ void ConfigAgentDelegate::drawFocus(QPainter *painter, const QStyleOptionViewIte
         o.state |= QStyle::State_KeyboardFocusChange;
         QPalette::ColorGroup cg = (option.state & QStyle::State_Enabled) ? QPalette::Normal : QPalette::Disabled;
         o.backgroundColor = option.palette.color(cg, (option.state & QStyle::State_Selected)
-                                                 ? QPalette::Highlight : QPalette::Background);
+                                                 ? QPalette::Highlight : QPalette::Window);
         QApplication::style()->drawPrimitive(QStyle::PE_FrameFocusRect, &o, painter);
     }
 }
