@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2011-2018 Montel Laurent <montel@kde.org>
+   Copyright (C) 2011-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -21,7 +21,7 @@
 #define KMKNOTIFY_H
 
 #include <QDialog>
-class KComboBox;
+class QComboBox;
 class KNotifyConfigWidget;
 
 namespace KMail {
@@ -42,7 +42,7 @@ private:
     void initCombobox();
     void writeConfig();
     void readConfig();
-    KComboBox *m_comboNotify = nullptr;
+    QComboBox *m_comboNotify = nullptr;
     KNotifyConfigWidget *m_notifyWidget = nullptr;
     bool m_changed = false;
 };
