@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2018 Montel Laurent <montel@kde.org>
+   Copyright (C) 2018-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -147,43 +147,48 @@ QHash<MessageComposer::PluginActionType::Type, QList<QAction *> > KMailPluginEdi
 {
     if (mActionHash.isEmpty()) {
         for (MessageComposer::PluginEditorConvertTextInterface *interface : qAsConst(mListPluginInterface)) {
-            const MessageComposer::PluginActionType actionType = interface->actionType();
-            MessageComposer::PluginActionType::Type type = actionType.type();
-            QList<QAction *> lst = mActionHash.value(type);
-            if (!lst.isEmpty()) {
-                QAction *act = new QAction(this);
-                act->setSeparator(true);
-                lst << act << actionType.action();
-                mActionHash.insert(type, lst);
-            } else {
-                mActionHash.insert(type, QList<QAction *>() << actionType.action());
-            }
-            /*
-            if (interface->plugin()->hasPopupMenuSupport()) {
-                type = MessageComposer::PluginActionType::PopupMenu;
+            for (const MessageComposer::PluginActionType &actionType : interface->actionTypes()) {
+                MessageComposer::PluginActionType::Type type = actionType.type();
+                QAction *currentAction = actionType.action();
+                if (!currentAction) {
+                    continue;
+                }
                 QList<QAction *> lst = mActionHash.value(type);
                 if (!lst.isEmpty()) {
                     QAction *act = new QAction(this);
                     act->setSeparator(true);
-                    lst << act << actionType.action();
+                    lst << act << currentAction;
                     mActionHash.insert(type, lst);
                 } else {
-                    mActionHash.insert(type, QList<QAction *>() << actionType.action());
+                    mActionHash.insert(type, QList<QAction *>() << currentAction);
+                }
+                if (interface->plugin()->hasPopupMenuSupport()) {
+                    type = MessageComposer::PluginActionType::PopupMenu;
+                    if (currentAction) {
+                        QList<QAction *> lst = mActionHash.value(type);
+                        if (!lst.isEmpty()) {
+                            QAction *act = new QAction(this);
+                            act->setSeparator(true);
+                            lst << act << currentAction;
+                            mActionHash.insert(type, lst);
+                        } else {
+                            mActionHash.insert(type, QList<QAction *>() << currentAction);
+                        }
+                    }
+                }
+                if (interface->plugin()->hasToolBarSupport()) {
+                    type = MessageComposer::PluginActionType::ToolBar;
+                    QList<QAction *> lst = mActionHash.value(type);
+                    if (!lst.isEmpty()) {
+                        QAction *act = new QAction(this);
+                        act->setSeparator(true);
+                        lst << act << currentAction;
+                        mActionHash.insert(type, lst);
+                    } else {
+                        mActionHash.insert(type, QList<QAction *>() << currentAction);
+                    }
                 }
             }
-            if (interface->plugin()->hasToolBarSupport()) {
-                type = MessageComposer::PluginActionType::ToolBar;
-                QList<QAction *> lst = mActionHash.value(type);
-                if (!lst.isEmpty()) {
-                    QAction *act = new QAction(this);
-                    act->setSeparator(true);
-                    lst << act << actionType.action();
-                    mActionHash.insert(type, lst);
-                } else {
-                    mActionHash.insert(type, QList<QAction *>() << actionType.action());
-                }
-            }
-            */
         }
     }
     return mActionHash;
