@@ -19,7 +19,7 @@
 #include "folderarchiveaccountinfotest.h"
 #include "../folderarchiveaccountinfo.h"
 #include <AkonadiCore/Collection>
-#include <qtest.h>
+#include <QTest>
 #include <KSharedConfig>
 #include <QStandardPaths>
 
