@@ -39,7 +39,7 @@ public:
     * @brief saveVcard
     * @return The file path for current vcard.
     */
-    QString saveVcard() const;
+    Q_REQUIRED_RESULT QString saveVcard() const;
 
     void reject() override;
 Q_SIGNALS:
