@@ -1663,11 +1663,21 @@ void KMKernel::cleanupTemporaryFiles()
     const QStringList lst = dir.entryList(QStringList{QStringLiteral("messageviewer_*")});
     qCDebug(KMAIL_LOG) << " list file to delete " << lst;
     for (const QString &file : lst) {
+        QFile tempFile(QDir::tempPath() + QLatin1Char('/') + file);
+        if (!tempFile.remove()) {
+            fprintf(stderr, "%s was not removed .\n", qPrintable(tempFile.fileName()));
+        } else {
+            fprintf(stderr, "%s was removed .\n", qPrintable(tempFile.fileName()));
+        }
+    }
+    const QStringList lstRepo = dir.entryList(QStringList{QStringLiteral("messageviewer_*.index.*")});
+    qCDebug(KMAIL_LOG) << " list repo to delete " << lstRepo;
+    for (const QString &file : lstRepo) {
         QDir tempDir(QDir::tempPath() + QLatin1Char('/') + file);
         if (!tempDir.removeRecursively()) {
-            fprintf(stderr, "%s was not removed .\n", qPrintable(tempDir.absolutePath()));
+            fprintf(stderr, "%s was not removed .\n", qPrintable(tempDir.path()));
         } else {
-            fprintf(stderr, "%s was removed .\n", qPrintable(tempDir.absolutePath()));
+            fprintf(stderr, "%s was removed .\n", qPrintable(tempDir.path()));
         }
     }
 }
