@@ -29,8 +29,6 @@
 #include "followupreminderinterface.h"
 #include "MailCommon/FilterManager"
 
-#include <QDBusInterface>
-#include <QDBusReply>
 #include <QProcess>
 #include "kmail_debug.h"
 #include <QStandardPaths>
@@ -96,11 +94,11 @@ void KMLaunchExternalComponent::slotImportWizard()
 
 void KMLaunchExternalComponent::slotExportData()
 {
-    const QString path = QStandardPaths::findExecutable(QStringLiteral("pimsettingexporter"));
+    const QString path = QStandardPaths::findExecutable(QStringLiteral("pimdataexporter"));
     if (!QProcess::startDetached(path)) {
-        KMessageBox::error(mParentWidget, i18n("Could not start \"PIM Setting Exporter\" program. "
+        KMessageBox::error(mParentWidget, i18n("Could not start \"PIM Data Exporter\" program. "
                                                "Please check your installation."),
-                           i18n("Unable to start \"PIM Setting Exporter\" program"));
+                           i18n("Unable to start \"PIM Data Exporter\" program"));
     }
 }
 
