@@ -44,7 +44,7 @@ public:
     /// Same as KMMainWin::restore(), except that it also restores the docked state,
     /// which we have saved in saveProperties().
     /// TODO: KDE5: Move to kdelibs, see http://reviewboard.kde.org/r/504
-    bool restoreDockedState(int number);
+    Q_REQUIRED_RESULT bool restoreDockedState(int number);
 
 public Q_SLOTS:
     void displayStatusMessage(const QString &);
