@@ -90,7 +90,7 @@ SummaryWidget::SummaryWidget(KontactInterface::Plugin *plugin, QWidget *parent)
         = new KViewStateMaintainer<Akonadi::ETMViewStateSaver>(_config->group("CheckState"), this);
     mModelState->setSelectionModel(mSelectionModel);
 
-    connect(mChangeRecorder, QOverload<const Akonadi::Collection &>::of(&Akonadi::ChangeRecorder::collectionChanged), this, &SummaryWidget::slotCollectionChanged);
+    connect(mChangeRecorder, qOverload<const Akonadi::Collection &>(&Akonadi::ChangeRecorder::collectionChanged), this, &SummaryWidget::slotCollectionChanged);
     connect(mChangeRecorder, &Akonadi::ChangeRecorder::collectionRemoved, this, &SummaryWidget::slotCollectionChanged);
     connect(mChangeRecorder, &Akonadi::ChangeRecorder::collectionStatisticsChanged, this, &SummaryWidget::slotCollectionChanged);
     QTimer::singleShot(0, this, &SummaryWidget::slotUpdateFolderList);
@@ -165,7 +165,7 @@ void SummaryWidget::displayModel(const QModelIndex &parent, int &counter, const
                                           stats.count(),
                                           stats.unreadCount()));
 
-                connect(urlLabel, QOverload<const QString &>::of(&KUrlLabel::leftClickedUrl), this, &SummaryWidget::selectFolder);
+                connect(urlLabel, qOverload<const QString &>(&KUrlLabel::leftClickedUrl), this, &SummaryWidget::selectFolder);
 
                 // Read and unread count.
                 QLabel *label = new QLabel(i18nc("%1: number of unread messages "
