@@ -435,8 +435,8 @@ void SummaryViewPart::slotConfigure()
     dlg->setModal(true);
 
     QStringList modules = configModules();
-    modules.prepend(QLatin1String("kcmkontactsummary.desktop"));
-    connect(dlg.data(), QOverload<>::of(&KCMultiDialog::configCommitted),
+    modules.prepend(QStringLiteral("kcmkontactsummary.desktop"));
+    connect(dlg.data(), qOverload<>(&KCMultiDialog::configCommitted),
             this, &SummaryViewPart::updateWidgets);
 
     QStringList::ConstIterator strIt;
