@@ -17,7 +17,7 @@
    Boston, MA 02110-1301, USA.
 */
 
-#include <qdebug.h>
+#include <QDebug>
 
 #include <QCoreApplication>
 #include <QCommandLineParser>
